# `/lib/pkgconfig`

Sample pkg config files for the NVidia libraries that don't usually come with one.

You may need to edit them and modify the paths.

These files should be placed in `/lib[64]/pkgconfig/`.
